pub enum SysSuspendRequest {
Callback {
enable_wake: bool,
suspend_reason: u8,
responder: SysSuspendCallbackResponder,
},
}Expand description
Servers that implement this protocol can be registered to the platform bus to receive callbacks on why the platform bus is suspending.
Variants
Callback
Invoked by the platform bus when its suspend hook is called.
Implementations
Sourceimpl SysSuspendRequest
impl SysSuspendRequest
pub fn into_callback(self) -> Option<(bool, u8, SysSuspendCallbackResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL