pub struct BootloaderInfo {
pub vendor: Option<String>,
/* private fields */
}Expand description
Bootloader information set by the board driver.
Fields
vendor: Option<String>Trait Implementations
Sourceimpl Clone for BootloaderInfo
impl Clone for BootloaderInfo
Sourcefn clone(&self) -> BootloaderInfo
fn clone(&self) -> BootloaderInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootloaderInfo
impl Debug for BootloaderInfo
Sourceimpl<D> Decode<BootloaderInfo, D> for BootloaderInfowhere
D: ResourceDialect,
impl<D> Decode<BootloaderInfo, D> for BootloaderInfowhere
D: ResourceDialect,
Sourcefn new_empty() -> BootloaderInfo
fn new_empty() -> BootloaderInfo
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for BootloaderInfo
impl Default for BootloaderInfo
Sourcefn default() -> BootloaderInfo
fn default() -> BootloaderInfo
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<BootloaderInfo, D> for &BootloaderInfowhere
D: ResourceDialect,
impl<D> Encode<BootloaderInfo, D> for &BootloaderInfowhere
D: ResourceDialect,
Sourceimpl PartialEq for BootloaderInfo
impl PartialEq for BootloaderInfo
Sourceimpl TypeMarker for BootloaderInfo
impl TypeMarker for BootloaderInfo
Sourcetype Owned = BootloaderInfo
type Owned = BootloaderInfo
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BootloaderInfo
impl ValueTypeMarker for BootloaderInfo
Sourcetype Borrowed<'a> = &'a BootloaderInfo
type Borrowed<'a> = &'a BootloaderInfo
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<BootloaderInfo as TypeMarker>::Owned,
) -> <BootloaderInfo as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<BootloaderInfo as TypeMarker>::Owned, ) -> <BootloaderInfo as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for BootloaderInfo
impl StructuralPartialEq for BootloaderInfo