pub struct InterruptAttributorGetInterruptInfoResponse {
pub device_name: String,
pub component_token: Option<Event>,
}Fields
device_name: StringThe name of the device which the board driver gave to the device the interrupt was assigned to.
component_token: Option<Event>Token that represents the driver component instance which the interrupt was given to. It may be be exchanged with the driver framework or component framework to learn more information about component, such as it’s URL or moniker.
If a driver has not yet bound to the device and taken control of the interrupt yet, it will not yet be present.