pub struct InterruptAttributorMarker;Trait Implementations
Sourceimpl Clone for InterruptAttributorMarker
impl Clone for InterruptAttributorMarker
Sourcefn clone(&self) -> InterruptAttributorMarker
fn clone(&self) -> InterruptAttributorMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterruptAttributorMarker
impl Debug for InterruptAttributorMarker
Sourceimpl Hash for InterruptAttributorMarker
impl Hash for InterruptAttributorMarker
Sourceimpl Ord for InterruptAttributorMarker
impl Ord for InterruptAttributorMarker
Sourcefn cmp(&self, other: &InterruptAttributorMarker) -> Ordering
fn cmp(&self, other: &InterruptAttributorMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for InterruptAttributorMarker
impl PartialOrd for InterruptAttributorMarker
Sourceimpl ProtocolMarker for InterruptAttributorMarker
impl ProtocolMarker for InterruptAttributorMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) InterruptAttributor"
const DEBUG_NAME: &'static str = "(anonymous) InterruptAttributor"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = InterruptAttributorProxy
type Proxy = InterruptAttributorProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = InterruptAttributorRequestStream
type RequestStream = InterruptAttributorRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = InterruptAttributorSynchronousProxy
type SynchronousProxy = InterruptAttributorSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for InterruptAttributorMarker
impl Eq for InterruptAttributorMarker
impl StructuralPartialEq for InterruptAttributorMarker