pub struct Mmio {
pub base: Option<u64>,
pub length: Option<u64>,
pub name: Option<String>,
/* private fields */
}Expand description
Definition of a MMIO resource for a platform device node.
Fields
base: Option<u64>Physical address of MMIO region. Does not need to be page aligned.
length: Option<u64>Length of MMIO region in bytes. Does not need to be page aligned.
name: Option<String>Name that can be used to retrieve the Mmio using
[fuchsia.hardware.platform.device/GetMmioByName].
It is valid for this to be empty, however the resource will only be able
to be retrieved using [fuchsia.hardware.platform.device/GetMmioById].