pub struct Node {Show 14 fields
pub name: Option<String>,
pub vid: Option<u32>,
pub pid: Option<u32>,
pub did: Option<u32>,
pub instance_id: Option<u32>,
pub mmio: Option<Vec<Mmio>>,
pub irq: Option<Vec<Irq>>,
pub bti: Option<Vec<Bti>>,
pub smc: Option<Vec<Smc>>,
pub metadata: Option<Vec<Metadata>>,
pub boot_metadata: Option<Vec<BootMetadata>>,
pub properties: Option<Vec<NodeProperty2>>,
pub power_config: Option<Vec<PowerElementConfiguration>>,
pub driver_host: Option<String>,
/* private fields */
}Expand description
Arguments for adding a platform device node to the platform bus.
Fields
name: Option<String>Name of the node.
vid: Option<u32>BIND_PLATFORM_DEV_VID
pid: Option<u32>BIND_PLATFORM_DEV_PID
did: Option<u32>BIND_PLATFORM_DEV_DID
instance_id: Option<u32>Instance ID. Contributes to device-name if non-zero.
BIND_PLATFORM_DEV_INSTANCE_ID
mmio: Option<Vec<Mmio>>MMIO regions.
irq: Option<Vec<Irq>>Interrupts.
bti: Option<Vec<Bti>>BTIs.
smc: Option<Vec<Smc>>SMC calls.
metadata: Option<Vec<Metadata>>Metadata
boot_metadata: Option<Vec<BootMetadata>>Boot metadata (from ZBI items)
properties: Option<Vec<NodeProperty2>>Other node properties beyond BIND_PLATFORM_DEV_VID, BIND_PLATFORM_DEV_PID, and BIND_PLATFORM_DEV_DID.
power_config: Option<Vec<PowerElementConfiguration>>driver_host: Option<String>Trait Implementations
Sourceimpl<D> Decode<Node, D> for Nodewhere
D: ResourceDialect,
impl<D> Decode<Node, D> for Nodewhere
D: ResourceDialect,
Sourceimpl TypeMarker for Node
impl TypeMarker for Node
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Node
impl ValueTypeMarker for Node
Sourcetype Borrowed<'a> = &'a Node
type Borrowed<'a> = &'a Node
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Node as TypeMarker>::Owned,
) -> <Node as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Node as TypeMarker>::Owned, ) -> <Node as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for Node
impl StructuralPartialEq for Node