pub struct Smc {
pub service_call_num_base: Option<u32>,
pub count: Option<u32>,
pub exclusive: Option<bool>,
pub name: Option<String>,
/* private fields */
}Expand description
Definition of a Secure Monitor Call (SMC), which allows calls to be made from the user space.
Fields
service_call_num_base: Option<u32>The device is granted the ability to make SMC calls with service call numbers ranging from service_call_num_base to service_call_num_base + count - 1.
count: Option<u32>exclusive: Option<bool>The device has exclusive access to this smc range.
name: Option<String>Name that can be used to retrieve the smc using
[fuchsia.hardware.platform.device/GetSmcByName].
It is valid for this to be empty, however the resource will only be able
to be retrieved using [fuchsia.hardware.platform.device/GetSmcById].