pub struct SysSuspendMarker;Trait Implementations
Sourceimpl Clone for SysSuspendMarker
impl Clone for SysSuspendMarker
Sourcefn clone(&self) -> SysSuspendMarker
fn clone(&self) -> SysSuspendMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SysSuspendMarker
impl Debug for SysSuspendMarker
Sourceimpl Hash for SysSuspendMarker
impl Hash for SysSuspendMarker
Sourceimpl Ord for SysSuspendMarker
impl Ord for SysSuspendMarker
Sourcefn cmp(&self, other: &SysSuspendMarker) -> Ordering
fn cmp(&self, other: &SysSuspendMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SysSuspendMarker
impl PartialEq for SysSuspendMarker
Sourceimpl PartialOrd for SysSuspendMarker
impl PartialOrd for SysSuspendMarker
Sourceimpl ProtocolMarker for SysSuspendMarker
impl ProtocolMarker for SysSuspendMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) SysSuspend"
const DEBUG_NAME: &'static str = "(anonymous) SysSuspend"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = SysSuspendProxy
type Proxy = SysSuspendProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = SysSuspendRequestStream
type RequestStream = SysSuspendRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = SysSuspendSynchronousProxy
type SynchronousProxy = SysSuspendSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for SysSuspendMarker
impl Eq for SysSuspendMarker
impl StructuralPartialEq for SysSuspendMarker