pub struct SysSuspendProxy { /* private fields */ }Implementations
Sourceimpl SysSuspendProxy
impl SysSuspendProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.platform.bus/SysSuspend.
Sourcepub fn take_event_stream(&self) -> SysSuspendEventStream
pub fn take_event_stream(&self) -> SysSuspendEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn callback(
&self,
enable_wake: bool,
suspend_reason: u8,
) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
pub fn callback( &self, enable_wake: bool, suspend_reason: u8, ) -> QueryResponseFut<i32, DefaultFuchsiaResourceDialect>
Invoked by the platform bus when its suspend hook is called.